# shajango


[![PyPI version](https://badge.fury.io/py/shajango.svg)](https://badge.fury.io/py/shajango)
![versions](https://img.shields.io/pypi/pyversions/shajango.svg)
[![GitHub license](https://img.shields.io/github/license/mgancita/shajango.svg)](https://github.com/mgancita/shajango/blob/main/LICENSE)


[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


一个基于Django的CMS。


- 开源许可: MIT
- 文档: https://llango.github.io/shajango.


## 特征

* TODO

## 制作


该包使用 [Cookiecutter](https://github.com/audreyr/cookiecutter) 和 [`llango/cookiecutter-mkdoc-shapackage`](https://github.com/llango/cookiecutter-mkdoc-shapackage/) 项目模版创建。
